@@ -13,8 +13,8 @@ use Module::Load;
 use String::ShellQuote;
 use Test::More 0.96;
 
-our $VERSION = '1.46'; # VERSION
-our $DATE = '2014-05-05'; # DATE
+our $VERSION = '1.47'; # VERSION
+our $DATE = '2014-06-12'; # DATE
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -68,8 +68,12 @@ sub test_dux_func {
                             };
                         }
                         is($res->[0], 200, "status");
-                        is_deeply($rout, $out, "out")
+                        if ($t->{test_out}) {
+                            $t->{test_out}->($rout);
+                        } else {
+                            is_deeply($rout, $out, "out")
                             or diag explain $rout;
+                        }
 
                         # if itemfunc, test against each item
                         if ('itemfunc' ~~ @{$meta->{tags}} &&
@@ -79,8 +83,12 @@ sub test_dux_func {
                             } else {
                                 my $rout;
                                 $rout = aiduxa([$fn, $t->{args}], $in);
-                                is_deeply($rout, $out, "itemfunc")
-                                    or diag explain $rout;
+                                if ($t->{test_out}) {
+                                    $t->{test_out}->($rout);
+                                } else {
+                                    is_deeply($rout, $out, "out")
+                                        or diag explain $rout;
+                                }
                             }
                         }
                     };
@@ -149,7 +157,7 @@ Test::Data::Unixish - Routines to test Data::Unixish
 
 =head1 VERSION
 
-This document describes version 1.46 of Test::Data::Unixish (from Perl distribution Data-Unixish), released on 2014-05-05.
+This document describes version 1.47 of Test::Data::Unixish (from Perl distribution Data-Unixish), released on 2014-06-12.
 
 =for Pod::Coverage .+
 
